function [Ceqdef,Jacdef] = DefPipe(nvar,into,colind,scl,def,itg)

% This function defines the definition values of the simple pipe model
%
%   Inlet p, T, and xi
%
% Hence, the inlet flow is defined via the recycle pressure and not the
% inlet flow.
%
% Written by Julian Straus, Trondheim 09.12.2018
%
% The input of this function is given by
%       nvar:   Total number of variables.
%
%       into:   Input values to the unit operation defined in the
%               flowsheet.
%
%       colind: Indexes of the columns i the Jacobian.
%
% The main output is defined as
%       Ceqdef: Cells containing the equality constraints of the
%               definitions.
%
%       Jacdef: Cells containing the rows of the Jacobian defined by the
%               definitions.
%
% The necessary structures and cells are defined as
%       scl:    Scaling factors of the system defined in cells representing
%               the unit operations defined in par.ReactSec.
%
%       def:    Defined stream values, e.g pressure and composition for all
%               inlets and the pressure of the outlets or the flow of the
%               inlets.


% Predefinition of the returning cells.
Jacdef = cell(def.sizeMat);
Ceqdef = Jacdef;

%% Definitions in Pipe 1
k = 1;
% Calculation of the equality constraints for the definition of compressor 1
Ceqdef{k+1} = (into{k}(1:itg.k).*scl{k}.Var(1:itg.k)'-def.FPipe).*scl{k}.DefEq;

% Calculation of the parts of the Jacobian defined by the definition of
% compressor 1
colind{k+1} = colind{k}(1:itg.k);
Jacdef{k+1} = sparse(1:numel(Ceqdef{k+1}),colind{k+1},scl{k}.DefEq'.*scl{k}.Var(1:itg.k),...
                     numel(Ceqdef{k+1}),nvar);
